@@ -3,18 +3,24 @@
 #'
 #' Calculates a matrix with uncorrelated columns using the Gram-Schmidt process
 #'
+#' This function, originally from the \pkg{heplots} package has now been deprecated in \pkg{matlib}. Use
+#' \code{\link{GramSchmidt}} instead.
+#'
 #' @param y a numeric matrix or data frame
 #' @param order if specified, a permutation of the column indices of \code{y}
 #' @param recenter logical; if \code{TRUE}, the result has same means as the original \code{y}, else means = 0 for cols 2:p
 #' @param rescale  logical; if \code{TRUE}, the result has same sd as original, else, sd = residual sd
 #' @param adjnames logical; if \code{TRUE}, colnames are adjusted to Y1, Y2.1, Y3.12, ...
 #' @return a matrix/data frame with uncorrelated columns
+#' @export
 #' @examples
+#' \dontrun{
 #'  set.seed(1234)
 #'  A <- matrix(c(1:60 + rnorm(60)), 20, 3)
 #'  cor(A)
 #'  G <- gsorth(A)
 #'  zapsmall(cor(G))
+#'  }
 
 # Return a matrix/data frame with uncorrelated columns
 #   recenter=TRUE -> result has same means as original, else means = 0 for cols 2:p
@@ -37,6 +43,7 @@ gsorth <- function(y, order, recenter=TRUE, rescale=TRUE, adjnames=TRUE) {
     else sqrt(var(as.vector(x), na.rm = na.rm))
   }
 
+  .Deprecated("GramSchmidt")
   n <- nrow(y)
   if (missing(order)) order <- 1:ncol(y)
   y <- y[,order]
