@@ -5,9 +5,11 @@
 #'
 #' @param x a matrix
 #' @param fractions logical; if \code{TRUE}, try to express non-integers as rational numbers
-#' @param brackets logical; include square brackets around the matricies?
+#' @param brackets logical; include square brackets around the matrices?
 #' @param ... additional arguments passed to \code{xtable::xtableMatharray()}
+#' @importFrom xtable xtableMatharray
 #' @author Phil Chalmers
+#' @export
 #' @examples
 #' A <- matrix(c(2, 1, -1,
 #'              -3, -1, 2,
@@ -19,12 +21,6 @@
 #' matrix2latex(cbind(A/2,b), fractions = TRUE)
 #'
 matrix2latex <- function(x, fractions = FALSE, brackets = TRUE, ...){
-  if (fractions) {
-    mass <- requireNamespace("MASS", quietly=TRUE)
-    if (!mass) stop("fractions=TRUE needs MASS package")
-  }
-  xtable <- requireNamespace("xtable", quietly=TRUE)
-  if (!xtable) stop("latex=TRUE needs xtable package")
   ret <- if (fractions) xtable::xtableMatharray(as.character(MASS::fractions(x)), ...)
     else xtable::xtableMatharray(x, ...)
   if(brackets) cat('\\left[\n ')
